Enum fmt_macros::CountUnstable
[-] [+]
[src]
pub enum Count<'a> {
CountIs(usize),
CountIsName(&'a str),
CountIsParam(usize),
CountIsNextParam,
CountImplied,
}A count is used for the precision and width parameters of an integer, and can reference either an argument or a literal integer.